@@ -1,9 +1,9 @@
 package Net::DNS::RR::CSYNC;
 
 #
-# $Id: CSYNC.pm 1528 2017-01-18 21:44:58Z willem $
+# $Id: CSYNC.pm 1561 2017-04-19 13:08:13Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1528 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1561 $)[1];
 
 
 use strict;
@@ -82,8 +82,7 @@ sub immediate {
 	my $bit = 0x0001;
 	for ( shift->{flags} ) {
 		my $set = $bit | ( $_ ||= 0 );
-		return $bit & $_ unless scalar @_;
-		$_ = (shift) ? $set : ( $set ^ $bit );
+		$_ = (shift) ? $set : ( $set ^ $bit ) if scalar @_;
 		return $_ & $bit;
 	}
 }
@@ -93,8 +92,7 @@ sub soaminimum {
 	my $bit = 0x0002;
 	for ( shift->{flags} ) {
 		my $set = $bit | ( $_ ||= 0 );
-		return $bit & $_ unless scalar @_;
-		$_ = (shift) ? $set : ( $set ^ $bit );
+		$_ = (shift) ? $set : ( $set ^ $bit ) if scalar @_;
 		return $_ & $bit;
 	}
 }
