@@ -15,13 +15,13 @@ sub UNITCHECK {				## restore %SIG after compilation
 package Net::DNS::RR::SIG;
 
 #
-# $Id: SIG.pm 1501 2016-08-25 14:57:12Z willem $
+# $Id: SIG.pm 1567 2017-05-19 09:52:52Z willem $
 #
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1501 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1567 $)[1];
 
 
 use strict;
+use warnings;
 use base qw(Net::DNS::RR);
 
 =head1 NAME
@@ -42,7 +42,7 @@ use Net::DNS::Parameters;
 
 use constant DEBUG => 0;
 
-use constant UTIL => defined eval 'require Scalar::Util';
+use constant UTIL => defined eval 'use Scalar::Util 1.25; 1;';
 
 use constant PRIVATE => defined eval 'require Net::DNS::SEC::Private';
 
@@ -92,8 +92,9 @@ sub _encode_rdata {			## encode rdata as wire-format octet string
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
+	my $signame = $self->{signame} || return '';
 	my @sig64 = split /\s+/, MIME::Base64::encode( $self->sigbin );
-	my @rdata = ( map( $self->$_, @field ), $self->{signame}->string, @sig64 );
+	my @rdata = ( map( $self->$_, @field ), $signame->string, @sig64 );
 }
 
 
@@ -121,7 +122,8 @@ sub _defaults {				## specify RR attribute default values
 # source: http://www.iana.org/assignments/dns-sec-alg-numbers
 #
 {
-	my @algbyname = (		## Reserved	=> 0,	# [RFC4034][RFC4398]
+	my @algbyname = (
+		'DELETE'	     => 0,			# [RFC4034][RFC4398][RFC8087]
 		'RSAMD5'	     => 1,			# [RFC3110][RFC4034]
 		'DH'		     => 2,			# [RFC2539]
 		'DSA'		     => 3,			# [RFC3755][RFC2536]
@@ -136,6 +138,8 @@ sub _defaults {				## specify RR attribute default values
 		'ECC-GOST'	     => 12,			# [RFC5933]
 		'ECDSAP256SHA256'    => 13,			# [RFC6605]
 		'ECDSAP384SHA384'    => 14,			# [RFC6605]
+		'ED25519'	     => 15,			# [RFC8080]
+		'ED448'		     => 16,			# [RFC8080]
 
 		'INDIRECT'   => 252,				# [RFC4034]
 		'PRIVATEDNS' => 253,				# [RFC4034]
@@ -145,21 +149,16 @@ sub _defaults {				## specify RR attribute default values
 
 	my %algbyval = reverse @algbyname;
 
-	my $map = sub {
-		my $arg = shift;
-		return $arg if $arg =~ /^\d/;
-		$arg =~ s/[^A-Za-z0-9]//g;			# strip non-alphanumerics
-		uc($arg);
-	};
-
-	my @pairedval = sort ( 1 .. 254, 1 .. 254 );		# also accept number
-	my %algbyname = map &$map($_), @algbyname, @pairedval;
+	my @algrehash = map /^\d/ ? ($_) x 3 : do { s/[\W]//g; uc($_) }, @algbyname;
+	my %algbyname = @algrehash;    # work around broken cperl
 
 	sub _algbyname {
-		my $name = shift;
-		my $key	 = uc $name;				# synthetic key
-		$key =~ s/[^A-Z0-9]//g;				# strip non-alphanumerics
-		$algbyname{$key} || croak "unknown algorithm $name";
+		my $arg = shift;
+		my $key = uc $arg;				# synthetic key
+		$key =~ s/[\W_]//g;				# strip non-alphanumerics
+		my $val = $algbyname{$key};
+		return $val if defined $val;
+		return $key =~ /^\d/ ? $arg : croak "unknown algorithm $arg";
 	}
 
 	sub _algbyval {
@@ -181,16 +180,11 @@ my %SEC = (
 	);
 
 my %siglen = (
-	1  => 128,
-	3  => 41,
-	5  => 256,
-	6  => 41,
-	7  => 256,
-	8  => 256,
-	10 => 256,
-	12 => 64,
-	13 => 64,
-	14 => 96,
+	1 => 128,
+	3 => 41,
+	5 => 256,
+	6 => 41,
+	7 => 256,
 	);
 
 
@@ -437,7 +431,7 @@ sub _ordered($$) {			## irreflexive 32-bit partial ordering
 	return defined $b unless defined $a;			# ( undef, any )
 	return 0 unless defined $b;				# ( any, undef )
 
-	# unwise to assume 32-bit arithmetic, or that integer overflow goes unpunished
+	# unwise to assume 64-bit arithmetic, or that 32-bit integer overflow goes unpunished
 	if ( $a < 0 ) {						# translate $a<0 region
 		$a = ( $a ^ 0x80000000 ) & 0xFFFFFFFF;		#  0	 <= $a < 2**31
 		$b = ( $b ^ 0x80000000 ) & 0xFFFFFFFF;		# -2**31 <= $b < 2**32
@@ -461,7 +455,7 @@ sub _string2time {			## parse time specification string
 	croak 'undefined time' unless defined $arg;
 	return int($arg) if length($arg) < 12;
 	my ( $y, $m, @dhms ) = unpack 'a4 a2 a2 a2 a2 a2', $arg . '00';
-	unless ( $arg gt '20380119031407' ) {			# calendar folding
+	if ( $arg lt '20380119031408' ) {			# calendar folding
 		return timegm( reverse(@dhms), $m - 1, $y ) if $y < 2026;
 		return timegm( reverse(@dhms), $m - 1, $y - 56 ) + $y2026;
 	} elsif ( $y > 2082 ) {
@@ -708,8 +702,8 @@ that comes with the ISC BIND distribution.
 The optional remaining arguments consist of ( name => value ) pairs
 as follows:
 
-	sigin  => 20161201010101,	# signature inception
-	sigex  => 20161201011101,	# signature expiration
+	sigin  => 20171201010101,	# signature inception
+	sigex  => 20171201011101,	# signature expiration
 	sigval => 10,			# validity window (minutes)
 
 The sigin and sigex values may be specified as Perl time values or as
